;==============================================================================
; Reset Vector
;------------------------------------------------------------------------------

; Notes:
;
; This file defines constants relating to the physical construction of the
; metronome oard. The firmware uses the following peripherals:
;
; TMR0  - Used the create a regularly occuring interrupt to drive the update
;         of the multiplexed seven segment displays, time speaker tone output
;         and create delays for button debouncing
;
; TMR1  - Used to create regular interrupts matching the 50% duty cycle of the
;         currently select BPM.
;
; TMR2  - Used to generate a PWM output fed to the speaker to create a tone used
;         to beat out the current BPM rate
;
; PORTA - Used to handle multiplex digit selects and button inputs.
;
; PORTB - Used to select the illuminated display segments and output a PWM wave
;         form to the speaker.

;==============================================================================
; Revision History:
;
; 2006-01-17 AJ Initial version
;------------------------------------------------------------------------------

OSC             equ     .4000000        ; Oscillator frequency
FOSC            equ     OSC / .4        ; Machine cycles per second
PRESCALE        equ     .8              ; Hardware prescaler setting for T1
POSTSCALE       equ     .8              ; Software postscaler setting for T1

;==============================================================================
; I/O Pin Assignments
;------------------------------------------------------------------------------

; Port A pin Assigments

LED_D1          equ     0               ; Connections to common anodes of
LED_D2          equ     1               ; the seven segment displays
LED_D3          equ     2

LED_PULSE       equ     3               ; LED used to indicate a beat.

SW_UP           equ     7               ; Switch inputs, normally pulled high
SW_DN           equ     5
SW_SPKR         equ     4

; PORT B pin Assignments

LED_A           equ     5               ; Connection to display segment
LED_B           equ     4               ; cathodes
LED_C           equ     2
LED_D           equ     1
LED_E           equ     0
LED_F           equ     6
LED_G           equ     7

PWM_SPKR        equ     3               ; PWM output to speaker

;==============================================================================
; Time Delays
;------------------------------------------------------------------------------

DEBOUNCE        equ     .10             ; Tick count for debounce
SLOW            equ     .50             ; Tick count for slow repeat

PULSE_TICKS     equ     .5              ; Tick count for PWM enabled
