                nolist
;==============================================================================
; Data EEPROM Access Macros
;------------------------------------------------------------------------------

; Notes:
;
;
; The 'pic.inc' and 'banks.inc' files must be included before 'eeprom.inc' is
; itself included.

;==============================================================================
; Revision History:
;
; 2006-01-21 AJ Initial version
;------------------------------------------------------------------------------

#if HAS_EEPROM

;==============================================================================
; 12-Bit/14-Bit Cores
;------------------------------------------------------------------------------

#if HAS_12_BIT_CORE | HAS_14_BIT_CORE

; The EEPROM_SET_ADDR macro saves the target EEPROM addess in WREG in the
; EEADR register file.

EEPROM_SET_ADDR macro
                BANKABS EEADR
                movwf   EEADR           ; Save target EEPROM address
                endm

; The EEPROM_READ macro causes a data read from the current target address
; to be performed. The recovered byte is left in WREG.

EEPROM_READ     macro
                BANKABS EECON1
#if HAS_FLASH
                bcf     EECON1,EEPGD    ; Ensure DATA EEPROM will be accessed
#endif
                bsf     EECON1,RD       ; Select READ operation 
                BANKABS EEDATA
                movf    EEDATA,W        ; And load the target byte into WREG
                endm

; The EEPROM_WRITE macro writes the byte in WREG to the DATA EEPROM at the
; current target address.
 
EEPROM_WRITE    macro
                BANKABS EEDATA
                movwf   EEDATA          ; Save the 
                BANKABS EECON1
#if HAS_FLASH
                bcf     EECON1,EEPGD    ; Ensure DATA EEPROM will be accessed
#endif
                bsf     EECON1,WREN     ; Enable the WRITE operation
#if HAS_INTERRUPTS
                bcf     STATUS,C        ; Copy the interrupt state to C
                btfsc   INTCON,GIE
                bsf     STATUS,C
                bcf     INTCON,GIE      ; Then disable interrupts
#endif
                movlw   h'55'           ; Execute unlock sequence
                movwf   EECON2
                movlw   h'aa'
                movwf   EECON2
                bsf     EECON1,WR       ; And initiate the WRITE
#if HAS_INTERRUPTS
                btfsc   STATUS,C        ; If interrupts where enabled at entry
                bsf     INTCON,GIE      ; Then turn them back on
#endif
                endm

; The EEPROM_WAIT macro waits for a write operation started by EEPROM_WRITE
; to finished.

EEPROM_WAIT     macro
                local   Wait
                BANKABS PIR1
Wait            btfss   PIR1,EEIF       ; Wait for the EEPROM interrupt flag 
                goto    Wait
                bcf     PIR1,EEIF       ; The clear the interrupt flag
                BANKABS EECON1
                bcf     EECON1,WREN     ; And disable the WRITE operation
                endm

#endif

;==============================================================================
; 16-Bit Cores
;------------------------------------------------------------------------------

#if HAS_16_BIT_CORE

; The EEPROM_SET_ADDR macro saves the target EEPROM addess in WREG in the
; EEADR register file.

EEPROM_SET_ADDR macro
                movwf   EEADR,A         ; Save target EEPROM address
                endm

; The EEPROM_READ macro causes a data read from the current target address
; to be performed. The recovered byte is left in WREG.

EEPROM_READ     macro
                bcf     EECON1,EEPGD,A  ; Ensure DATA EEPROM will be accessed
                bcf     EECON1,CFGS,A
                bsf     EECON1,RD,A     ; Select READ operation 
                movf    EEDATA,W,A      ; And load the target byte into WREG
                endm

; The EEPROM_WRITE macro writes the byte in WREG to the DATA EEPROM at the
; current target address.
 
EEPROM_WRITE    macro
                movwf   EEDATA          ; Save the 
                bcf     EECON1,EEPGD,A  ; Ensure DATA EEPROM will be accessed
                bcf     EECON1,CFGS,A
                bsf     EECON1,WREN,A   ; Enable the WRITE operation
                bcf     STATUS,C,A      ; Copy the interrupt state to C
                btfss   INTCON,GIE,A
                bsf     STATUS,C,A
                bcf     INTCON,GIE,A    ; Then disable interrupts
                movlw   h'55'           ; Execute unlock sequence
                movwf   EECON2,A
                movlw   h'aa'
                movwf   EECON2,A
                bsf     EECON1,WR,A     ; And initiate the WRITE
                btfsc   STATUS,C,A      ; If interrupts where enabled at entry
                bsf     INTCON,GIE,A    ; Then turn them back on
                endm

; The EEPROM_WAIT macro waits for a write operation started by EEPROM_WRITE
; to finished.

EEPROM_WAIT     macro
                local   Wait
Wait            btfss   PIR1,EEIF,A     ; Wait for the EEPROM interrupt flag 
                bra     Wait
                bcf     PIR1,EEIF,A     ; The clear the interrupt flag
                bcf     EECON1,WREN,A   ; And disable the WRITE operation
                endm
 
#endif

#else
                error        "The current processor type does not have EEPROM"
#endif

                list
