                nolist
;==============================================================================
; Hexadecimal Patterns for Seven Segment Displays
;------------------------------------------------------------------------------

; Notes:
;
; The HEX_PATTERNS macro generates a series of RETLW instructions which return
; bit patterns corresponding to the segments required to display hexadecimal
; digits (0-F) on a seven segment LED.
;
; The arguments to macro can be used to define which port bit is controlling
; each of the segments A thru G. For example:
;
;       HEX_PATTERNS    0,1,2,3,4,5,6,7         ; A is bit 0, G is bit 7
;       HEX_PATTERNS    7,6,5,4,3,2,1,0         ; A is bit 7, G is bit 0
;
; If a segment is not needed then specificy -1 as its argument value.
;
; The pattern returned has '1' bits for segments that should be enabled and
; '0's for those that are not. For some circuits this may need to be inverted
; (XORLW H'FF') to match the required hardware signals.

;==============================================================================
; Revision History:
;
; 2006-01-19 AJ Initial version
;------------------------------------------------------------------------------

HEX_PATTERNS	macro	SA,SB,SC,SD,SE,SF,SG
	      	retlw	(1<<SA)|(1<<SB)|(1<<SC)|(1<<SD)|(1<<SE)|(1<<SF)
		retlw	        (1<<SB)|(1<<SC)
                retlw   (1<<SA)|(1<<SB)|        (1<<SD)|(1<<SE)|        (1<<SG)
                retlw   (1<<SA)|(1<<SB)|(1<<SC)|(1<<SD)|                (1<<SG)
                retlw           (1<<SB)|(1<<SC)|                (1<<SF)|(1<<SG)
                retlw   (1<<SA)|        (1<<SC)|(1<<SD)|        (1<<SF)|(1<<SG)
                retlw   (1<<SA)|        (1<<SC)|(1<<SD)|(1<<SE)|(1<<SF)|(1<<SG)
                retlw   (1<<SA)|(1<<SB)|(1<<SC)
                retlw   (1<<SA)|(1<<SB)|(1<<SC)|(1<<SD)|(1<<SE)|(1<<SF)|(1<<SG)
                retlw   (1<<SA)|(1<<SB)|(1<<SC)|                (1<<SF)|(1<<SG)
                retlw   (1<<SA)|(1<<SB)|(1<<SC)|        (1<<SE)|(1<<SF)|(1<<SG)
                retlw                   (1<<SC)|(1<<SD)|(1<<SE)|(1<<SF)|(1<<SG)
                retlw                           (1<<SD)|(1<<SE)|        (1<<SG)
                retlw           (1<<SB)|(1<<SC)|(1<<SD)|(1<<SE)|        (1<<SG)
                retlw   (1<<SA)|            (    1<<SD)|(1<<SE)|(1<<SF)|(1<<SG)
                retlw   (1<<SA)|                        (1<<SE)|(1<<SF)|(1<<SG)
                endm

                list
